/* Copyright (C) 2000-2003 Markus Lausser (sgop@users.sf.net)
   This is free software distributed under the terms of the
   GNU Public License.  See the file COPYING for details. */

void on_banned_users_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_connect_activate(GtkMenuItem * menuitem, 
			 gpointer user_data);
void on_disconnect_activate(GtkMenuItem * menuitem, 
			    gpointer user_data);
void on_button171_clicked(GtkButton * button, gpointer user_data);

void on_preferences_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_exit_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_join_chatrooms_activate(GtkMenuItem * menuitem, gpointer user_data);


void on_button18_clicked(GtkButton * button, gpointer user_data);

void on_menu_exit_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_exit_activate(GtkMenuItem * menuitem, gpointer user_data);


void on_about_win_destroy(GtkObject * object, gpointer user_data);

void on_options_win_destroy(GtkObject * object, gpointer user_data);

void on_button6_clicked(GtkButton * button, gpointer user_data);

void on_button7_clicked(GtkButton * button, gpointer user_data);

void
on_search_list_click_column(GtkCList * clist,
			    gint column, gpointer user_data);

void on_button29_clicked(GtkButton * button, gpointer user_data);

void on_button26_clicked(GtkButton * button, gpointer user_data);

void on_button27_clicked(GtkButton * button, gpointer user_data);

void on_button28_clicked(GtkButton * button, gpointer user_data);

void on_button30_clicked(GtkButton * button, gpointer user_data);

void on_button31_clicked(GtkButton * button, gpointer user_data);

void on_ok_button1_clicked(GtkButton * button, gpointer user_data);

void on_cancel_button1_clicked(GtkButton * button, gpointer user_data);

void on_connection_win_destroy(GtkObject * object, gpointer user_data);


void on_button33_clicked(GtkButton * button, gpointer user_data);

void on_button10_clicked(GtkButton * button, gpointer user_data);

void
on_remove_selected2_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_about_win_destroy(GtkObject * object, gpointer user_data);

void on_chat_close_clicked(GtkButton * button, gpointer user_data);

void on_chat_entry_activate(GtkEditable * editable, gpointer user_data);

void
on_notebook3_switch_page(GtkNotebook * notebook,
			 GtkNotebookPage * page,
			 gint page_num, gpointer user_data);


// LIST BUTTON PRESSED
gboolean
on_lib_list_button_press_event(GtkWidget * widget,
			       GdkEventButton * event, gpointer user_data);
gboolean
on_search_list_button_press_event(GtkWidget * widget,
				  GdkEventButton * event,
				  gpointer user_data);


// DOWNLOAD
void
on_download_resume_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_download_wd_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_download_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_download_selected_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_download_selected_wd_activate(GtkMenuItem * menuitem,
				 gpointer user_data);
gboolean
on_online_button_press_event(GtkWidget * widget,
			     GdkEventButton * event, gpointer user_data);
void
on_add_to_hot_list_activate(GtkMenuItem * menuitem, gpointer user_data);
// LIST 
void
on_list_click_column(GtkCList * clist, gint column, gpointer user_data);


void on_chat_entry_activate(GtkEditable * editable, gpointer user_data);

void on_stop_clicked(GtkButton * button, gpointer user_data);

void on_play_clicked(GtkButton * button, gpointer user_data);

gboolean
on_transfer_down_button_press_event(GtkWidget * widget,
				    GdkEventButton * event,
				    gpointer user_data);

void
on_cancel_download_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_delete_upload_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_delete_transfer_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_allow_upload_activate(GtkMenuItem * menuitem, gpointer user_data);
void
on_retry_download_activate(GtkMenuItem * menuitem, gpointer user_data);
void
on_force_download_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_resume_download_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_resume_play_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_stop_download_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_search_artist_activate(GtkEditable * editable, gpointer user_data);

void
on_search_results_activate(GtkEditable * editable, gpointer user_data);

gboolean
on_chat_entry_key_press_event(GtkWidget * widget,
			      GdkEventKey * event, gpointer user_data);

void on_whois_win_destroy(GtkObject * object, gpointer user_data);

void on_button82_clicked(GtkButton * button, gpointer user_data);

gboolean
on_transfer_up_button_press_event(GtkWidget * widget,
				  GdkEventButton * event,
				  gpointer user_data);

void
on_togglebutton2_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void on_button84_clicked(GtkButton * button, gpointer user_data);

void on_button87_clicked(GtkButton * button, gpointer user_data);

void on_button88_clicked(GtkButton * button, gpointer user_data);

void
on_handlebox1_child_attached(GtkHandleBox * handlebox,
			     GtkWidget * widget, gpointer user_data);
void on_button90_clicked(GtkButton * button, gpointer user_data);

void
on_add_to_hotlist_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_whois_user_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_ignore_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_subscribe_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_unignore_user_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_show_ignore_list_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_ignore_win_destroy(GtkObject * object, gpointer user_data);

void
on_refresh_users_files_activate(GtkMenuItem * menuitem,
				gpointer user_data);

void
on_remove_user_from_hotlist_activate(GtkMenuItem * menuitem,
				     gpointer user_data);
void
on_remove_from_hotlist_activate(GtkMenuItem * menuitem,
				gpointer user_data);

void on_download2_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_download_selected1_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_download_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_download_selected_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_download2_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_hidden_toggle_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void on_button96_clicked(GtkButton * button, gpointer user_data);

void on_combo_entry15_changed(GtkEditable * editable, gpointer user_data);


void on_button102_clicked(GtkButton * button, gpointer user_data);


void on_fileselection1_destroy(GtkObject * object, gpointer user_data);

void on_ban_win_destroy(GtkObject * object, gpointer user_data);

void on_server_win_destroy(GtkObject * object, gpointer user_data);
void on_button105_clicked(GtkButton * button, gpointer user_data);

void on_button94_clicked(GtkButton * button, gpointer user_data);

void on_button106_clicked(GtkButton * button, gpointer user_data);

void on_button107_clicked(GtkButton * button, gpointer user_data);

void
on_colorselectiondialog1_destroy(GtkObject * object, gpointer user_data);

void on_cancel_button2_clicked(GtkButton * button, gpointer user_data);

void
on_fontselectiondialog1_destroy(GtkObject * object, gpointer user_data);

void on_cancel_button3_clicked(GtkButton * button, gpointer user_data);

void on_ok_button2_clicked(GtkButton * button, gpointer user_data);

void on_button100_clicked(GtkButton * button, gpointer user_data);

void on_ok_button3_clicked(GtkButton * button, gpointer user_data);

void on_apply_button1_clicked(GtkButton * button, gpointer user_data);

void on_button108_clicked(GtkButton * button, gpointer user_data);

void on_user_win_destroy(GtkObject * object, gpointer user_data);

void
on_clist4_click_column(GtkCList * clist, gint column, gpointer user_data);

void on_button111_clicked(GtkButton * button, gpointer user_data);

void on_button112_clicked(GtkButton * button, gpointer user_data);


void on_button_users_clicked(GtkButton * button, gpointer user_data);
void
on_checkbutton7_toggled(GtkToggleButton * togglebutton,
			gpointer user_data);

void on_button115_clicked(GtkButton * button, gpointer user_data);

void on_button119_clicked(GtkButton * button, gpointer user_data);

void
on_checkbutton8_toggled(GtkToggleButton * togglebutton,
			gpointer user_data);

void on_button120_clicked(GtkButton * button, gpointer user_data);

void on_button121_clicked(GtkButton * button, gpointer user_data);

void on_button98_clicked(GtkButton * button, gpointer user_data);

void on_button99_clicked(GtkButton * button, gpointer user_data);

void
on_instant_message_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_cancel_button2_clicked(GtkButton * button, gpointer user_data);

void on_NULL_button2_clicked(GtkButton * button, gpointer user_data);

void on_NULL_button1_clicked(GtkButton * button, gpointer user_data);

void
on_checkbutton11_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

gboolean
on_entry46_key_press_event(GtkWidget * widget,
			   GdkEventKey * event, gpointer user_data);

void on_entry17_activate(GtkEditable * editable, gpointer user_data);

void on_whipser_mode_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_private_mode_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_whisper_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_button127_clicked(GtkButton * button, gpointer user_data);

void on_button128_clicked(GtkButton * button, gpointer user_data);

void on_button129_clicked(GtkButton * button, gpointer user_data);

void on_spinbutton8_changed(GtkEditable * editable, gpointer user_data);

void on_button133_clicked(GtkButton * button, gpointer user_data);

void on_friend_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_enemy_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_nodownload_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_button134_clicked(GtkButton * button, gpointer user_data);

void on_download_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_download_selected_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_refresh_shared_list1_activate(GtkMenuItem * menuitem,
				 gpointer user_data);

void on_refresh1_activate(GtkMenuItem * menuitem, gpointer user_data);

gboolean
on_search_list_button_press_event(GtkWidget * widget,
				  GdkEventButton * event,
				  gpointer user_data);

void on_search_artist_activate(GtkEditable * editable, gpointer user_data);

gboolean
on_window_key_press_event(GtkWidget * widget,
			  GdkEventKey * event, gpointer user_data);

void on_about_destroy(GtkObject * object, gpointer user_data);

void on_button145_clicked(GtkButton * button, gpointer user_data);

void on_about1_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_transfer_resize_column(GtkCList * clist,
			  gint column, gint width, gpointer user_data);

void on_button146_clicked(GtkButton * button, gpointer user_data);

void
on_clear_selected_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_clear_users_files_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_clear_all_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_clear_all_searches_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_clear_all_match_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_search_again_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_search_all_again_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_ctree1_tree_select_row(GtkCTree * ctree,
			  GtkCTreeNode * node,
			  gint column, gpointer user_data);

void on_usermode_win_destroy(GtkObject * object, gpointer user_data);

void on_button147_clicked(GtkButton * button, gpointer user_data);

void on_button148_clicked(GtkButton * button, gpointer user_data);

void on_client_win_destroy(GtkObject * object, gpointer user_data);

void on_button149_clicked(GtkButton * button, gpointer user_data);

void on_button150_clicked(GtkButton * button, gpointer user_data);

void
on_customize_list_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_customize_win_destroy(GtkObject * object, gpointer user_data);

void on_button1x_clicked(GtkButton * button, gpointer user_data);

void on_button2x_clicked(GtkButton * button, gpointer user_data);

void
on_linked_servers_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_client_statistic_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_whois_user1_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_refresh_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_button162_clicked(GtkButton * button, gpointer user_data);

void on_resume_search_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_resume_freeze_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_resume_thaw_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_resume_delete_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_resume_cancel_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_refresh_list_activate(GtkMenuItem * menuitem, gpointer user_data);

gboolean
on_clist12_button_press_event(GtkWidget * widget,
			      GdkEventButton * event, gpointer user_data);

void on_global_users_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_user_win_destroy(GtkObject * object, gpointer user_data);

void on_button164_clicked(GtkButton * button, gpointer user_data);

void on_button165_clicked(GtkButton * button, gpointer user_data);

void
on_transfer_down_select_row(GtkCList * clist,
			    gint row,
			    gint column,
			    GdkEvent * event, gpointer user_data);

void on_spinbutton15_changed(GtkEditable * editable, gpointer user_data);
void on_online_save_clicked(GtkButton * button, gpointer user_data);

void
on_ctree2_tree_select_row(GtkCTree * ctree,
			  GtkCTreeNode * node,
			  gint column, gpointer user_data);

void
on_notebook2_switch_page(GtkNotebook * notebook,
			 GtkNotebookPage * page,
			 gint page_num, gpointer user_data);

void on_button169_clicked(GtkButton * button, gpointer user_data);

void on_button166_clicked(GtkButton * button, gpointer user_data);

void on_button140_clicked(GtkButton * button, gpointer user_data);

void on_button139_clicked(GtkButton * button, gpointer user_data);

void on_button143_clicked(GtkButton * button, gpointer user_data);

void on_button141_clicked(GtkButton * button, gpointer user_data);

void on_button142_clicked(GtkButton * button, gpointer user_data);

void on_button144_clicked(GtkButton * button, gpointer user_data);

void on_delete_win_destroy(GtkObject * object, gpointer user_data);

void
on_notebook1_switch_page(GtkNotebook * notebook,
			 GtkNotebookPage * page,
			 gint page_num, gpointer user_data);

void on_log_win_destroy(GtkObject * object, gpointer user_data);

void on_button173_clicked(GtkButton * button, gpointer user_data);

void on_logfiles_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_clist14_select_row(GtkCList * clist,
		      gint row,
		      gint column, GdkEvent * event, gpointer user_data);

void
on_checkbutton30_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void
on_checkbutton33_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

gboolean
on_browse_list_button_event(GtkWidget * widget,
			    GdkEventButton * event, gpointer user_data);

void on_browse_files_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_combo_entry17_changed(GtkEditable * editable, gpointer user_data);

void on_button184_clicked(GtkButton * button, gpointer user_data);

void on_changes_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mode_error_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mode_ban_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mode_change_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mode_kill_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mode_activate(GtkMenuItem * menuitem, gpointer user_data);


void on_button186_clicked(GtkButton * button, gpointer user_data);

void
on_checkbutton16_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void on_kill_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_ban_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_locate_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_send_file_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_nuke_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_muzzle_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_chmuzzle_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_chban_activate(GtkMenuItem * menuitem, gpointer user_data);
void on_kick_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_safe_exit_activate(GtkMenuItem * menuitem, gpointer user_data);

gboolean
on_window_focus_in_event(GtkWidget * widget,
			 GdkEventFocus * event, gpointer user_data);

gboolean
on_window_focus_out_event(GtkWidget * widget,
			  GdkEventFocus * event, gpointer user_data);
void on_button191_clicked(GtkButton * button, gpointer user_data);
void on_extra_win_destroy(GtkObject * object, gpointer user_data);

gboolean
on_text_button_press_event(GtkWidget * widget,
			   GdkEventButton * event, gpointer user_data);

void on_chat_leave_clicked(GtkButton * button, gpointer user_data);
void on_chat_attach_clicked(GtkButton * button, gpointer user_data);
void on_chat_destroy(GtkWidget * window, gpointer user_data);

void on_button203_clicked(GtkButton * button, gpointer user_data);

void on_button204_clicked(GtkButton * button, gpointer user_data);

void
on_known_problems_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_checkbutton42_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void
on_checkbutton43_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

gboolean
on_drawingarea1_expose_event(GtkWidget * widget,
			     GdkEventExpose * event, gpointer user_data);

gboolean
on_drawingarea2_expose_event(GtkWidget * widget,
			     GdkEventExpose * event, gpointer user_data);

void on_button206_clicked(GtkButton * button, gpointer user_data);

void on_button207_clicked(GtkButton * button, gpointer user_data);

void on_button208_clicked(GtkButton * button, gpointer user_data);

void on_button209_clicked(GtkButton * button, gpointer user_data);

gboolean
on_drawingarea1_button_press_event(GtkWidget * widget,
				   GdkEventButton * event,
				   gpointer user_data);

gboolean
on_drawingarea2_button_press_event(GtkWidget * widget,
				   GdkEventButton * event,
				   gpointer user_data);

void on_button210_clicked(GtkButton * button, gpointer user_data);

gboolean
on_window_delete_event(GtkWidget * widget,
		       GdkEvent * event, gpointer user_data);

void on_show_sockets_activate(GtkMenuItem * menuitem, gpointer user_data);

gboolean
on_socket_win_delete_event(GtkWidget * widget,
			   GdkEvent * event, gpointer user_data);

void
on_notebook5_switch_page(GtkNotebook * notebook,
			 GtkNotebookPage * page,
			 gint page_num, gpointer user_data);

void on_button218_clicked(GtkButton * button, gpointer user_data);

gboolean
on_drawingarea1_motion_notify_event(GtkWidget * widget,
				    GdkEventMotion * event,
				    gpointer user_data);

gboolean
on_drawingarea2_motion_notify_event(GtkWidget * widget,
				    GdkEventMotion * event,
				    gpointer user_data);

void on_button217_clicked(GtkButton * button, gpointer user_data);

void on_socket_win_destroy(GtkObject * object, gpointer user_data);

void
on_clist20_select_row(GtkCList * clist,
		      gint row,
		      gint column, GdkEvent * event, gpointer user_data);

void on_window_destroy(GtkObject * object, gpointer user_data);
gboolean
on_extra_win_delete(GtkWidget * widget,
		    GdkEvent * event, gpointer user_data);

void on_detach_server_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_detach_chat_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_detach_library_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_detach_search_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_detach_hotlist_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_detach_downloads_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_detach_uploads_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_button228_clicked(GtkButton * button, gpointer user_data);

void on_button229_clicked(GtkButton * button, gpointer user_data);

gboolean
on_ignore_list_button_press_event(GtkWidget * widget,
				  GdkEventButton * event,
				  gpointer user_data);

void
on_checkbutton19_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void on_button231_clicked(GtkButton * button, gpointer user_data);

void on_button230_clicked(GtkButton * button, gpointer user_data);

void on_button232_clicked(GtkButton * button, gpointer user_data);

void
on_search_select_row(GtkCList * clist,
		     gint row,
		     gint column, GdkEvent * event, gpointer user_data);

void on_button237_clicked(GtkButton * button, gpointer user_data);

void on_button238_clicked(GtkButton * button, gpointer user_data);

void on_button243_clicked(GtkButton * button, gpointer user_data);

void on_button244_clicked(GtkButton * button, gpointer user_data);

void on_button241_clicked(GtkButton * button, gpointer user_data);

void on_button242_clicked(GtkButton * button, gpointer user_data);

void on_button245_clicked(GtkButton * button, gpointer user_data);

void on_spinbutton49_changed(GtkEditable * editable, gpointer user_data);

void
on_transfer_up_select_row(GtkCList * clist,
			  gint row,
			  gint column,
			  GdkEvent * event, gpointer user_data);

void
on_checkbutton48_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void
on_checkbutton49_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void
on_checkbutton45_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void on_combo_entry25_changed(GtkEditable * editable, gpointer user_data);

void
on_detach_statistic_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_search_close_clicked(GtkButton * button, gpointer user_data);

gboolean
on_clist16_button_press_event(GtkWidget * widget,
			      GdkEventButton * event, gpointer user_data);

gboolean
on_drawingarea3_expose_event(GtkWidget * widget,
			     GdkEventExpose * event, gpointer user_data);

gboolean
on_drawingarea4_expose_event(GtkWidget * widget,
			     GdkEventExpose * event, gpointer user_data);

void on_button275_clicked(GtkButton * button, gpointer user_data);

void on_button276_clicked(GtkButton * button, gpointer user_data);

void on_resume_configure(GtkMenuItem * menuitem, gpointer user_data);

void
on_checkbutton51_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void
on_checkbutton52_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void
on_checkbutton53_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);


void on_combo_entry13_changed(GtkEditable * editable, gpointer user_data);

gboolean
on_drawingarea10_expose_event(GtkWidget * widget,
			      GdkEventExpose * event, gpointer user_data);

gboolean
on_browse_motion_notify_event(GtkWidget * widget,
			      GdkEventMotion * event, gpointer user_data);

void
on_checkbutton59_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void on_spinbutton61_changed(GtkEditable * editable, gpointer user_data);

void
on_checkbutton64_toggled(GtkToggleButton * togglebutton,
			 gpointer user_data);

void on_spinbutton62_changed(GtkEditable * editable, gpointer user_data);

gboolean
on_ctree3_button_press_event(GtkWidget * widget,
			     GdkEventButton * event, gpointer user_data);
void
on_latest_version_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_button308_clicked(GtkButton * button, gpointer user_data);

void on_button311_clicked(GtkButton * button, gpointer user_data);

void on_button313_clicked(GtkButton * button, gpointer user_data);

void on_button314_clicked(GtkButton * button, gpointer user_data);

void on_user_list_win_destroy(GtkObject * object, gpointer user_data);
void on_button315_clicked(GtkButton * button, gpointer user_data);
void on_user_list_activate(GtkMenuItem * menuitem, gpointer user_data);

gboolean
on_ctree4_button_press_event(GtkWidget * widget,
			     GdkEventButton * event, gpointer user_data);

gboolean
on_server_ctree_button_press_event(GtkWidget * widget,
				   GdkEventButton * event,
				   gpointer user_data);

void
on_enter_bandwidth1_activate(GtkMenuItem * menuitem, gpointer user_data);
void
on_enter_bandwidth2_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_download_man_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button318_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button319_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_ctree4_tree_select_row              (GtkCTree        *ctree,
                                        GList           *node,
                                        gint             column,
                                        gpointer         user_data);

gboolean
on_drawingarea12_expose_event          (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea12_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea12_leave_notify_event    (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

gboolean
on_drawingarea12_enter_notify_event    (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

gboolean
on_drawingarea11_expose_event          (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea11_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea11_enter_notify_event    (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

gboolean
on_drawingarea11_motion_notify_event   (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea11_leave_notify_event    (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

gboolean
on_drawingarea12_motion_notify_event   (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

void
on_button322_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_queue_win_destroy                   (GtkObject       *object,
                                        gpointer         user_data);

void
on_button323_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button325_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button324_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkbutton70_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button326_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button327_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_clist34_select_row                  (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_clist34_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_clist34_key_press_event             (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_item2_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item3_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button328_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button330_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button331_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button332_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button334_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button335_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_show_subscriptions_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_subscription_win_destroy            (GtkObject       *object,
                                        gpointer         user_data);

gboolean
on_ctree7_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_ctree7_drag_data_received           (GtkWidget       *widget,
                                        GdkDragContext  *drag_context,
                                        gint             x,
                                        gint             y,
                                        GtkSelectionData *data,
                                        guint            info,
                                        guint            time,
                                        gpointer         user_data);

void
on_button336_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry131_activate                   (GtkEditable     *editable,
                                        gpointer         user_data);

void on_sub_remove_activate(GtkMenuItem * menuitem, gpointer user_data);

void
on_button337_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button338_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button339_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_ctree8_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_clist36_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_clist36_drag_begin                  (GtkWidget       *widget,
                                        GdkDragContext  *drag_context,
                                        gpointer         user_data);

void
on_clist36_drag_data_get               (GtkWidget       *widget,
                                        GdkDragContext  *drag_context,
                                        GtkSelectionData *data,
                                        guint            info,
                                        guint            time,
                                        gpointer         user_data);

void
on_clist36_drag_end                    (GtkWidget       *widget,
                                        GdkDragContext  *drag_context,
                                        gpointer         user_data);

void
on_button343_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button344_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_clist19_select_row                  (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_ctree10_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_channel_button_press_event(GtkWidget * widget,
			      GdkEventButton * event, gpointer user_data);

void
on_button164_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancel_connect_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void on_add_subscription_activate(GtkMenuItem * menuitem,
				  gpointer user_data);

void
on_button347_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_drawingarea13_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea13_expose_event          (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

void
on_clist37_select_row                  (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_drawingarea14_expose_event          (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

void
on_button348_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry134_activate                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_entry135_activate                   (GtkEditable     *editable,
                                        gpointer         user_data);

gboolean
on_drawingarea14_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea14_motion_notify_event   (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

void
on_button349_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_ctree10_tree_select_row             (GtkCTree        *ctree,
                                        GList           *node,
                                        gint             column,
                                        gpointer         user_data);

void
on_entry137_activate                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_button350_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_clist39_select_row                  (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_clist40_select_row                  (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_checkbutton74_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_clist40_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea15_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea15_expose_event          (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea15_motion_notify_event   (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

void
on_entry141_activate                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_button351_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button352_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button353_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_radiobutton6_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_radiobutton7_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_spinbutton74_changed                (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_spinbutton75_changed                (GtkEditable     *editable,
                                        gpointer         user_data);

gboolean
on_ctree4_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_ctree4_tree_select_row              (GtkCTree        *ctree,
                                        GList           *node,
                                        gint             column,
                                        gpointer         user_data);

void
on_button355_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button354_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_clist43_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);
gboolean
on_browse_tree_button_event(GtkWidget * widget,
			    GdkEventButton * event,
			    gpointer user_data);

void
on_spinbutton78_changed                (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_spinbutton79_changed                (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_checkbutton68_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button357_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button358_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button356_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button215_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button214_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button316_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button216_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button185_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button359_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button187_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button345_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button360_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button361_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button189_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button346_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_combo_entry33_changed               (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_combo_entry28_changed               (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_checkbutton83_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_clist39_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_checkbutton88_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton89_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_drawingarea3_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea4_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_ctree8_drag_begin                   (GtkWidget       *widget,
                                        GdkDragContext  *drag_context,
                                        gpointer         user_data);

void
on_ctree8_drag_data_get                (GtkWidget       *widget,
                                        GdkDragContext  *drag_context,
                                        GtkSelectionData *data,
                                        guint            info,
                                        guint            time,
                                        gpointer         user_data);

void
on_ctree8_drag_end                     (GtkWidget       *widget,
                                        GdkDragContext  *drag_context,
                                        gpointer         user_data);

void
on_checkbutton90_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_drawingarea12_configure_event       (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_configure_event        (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea11_configure_event       (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea2_configure_event        (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);
void
on_button364_clicked (GtkButton       *button,
		      gpointer         user_data);

void
on_checkbutton92_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton93_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton94_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button365_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void on_special_users_activate();
